"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.readEngrave = exports.engrave = exports.defaultOptions = void 0;
const child_process_1 = require("child_process");
const fs_1 = __importDefault(require("fs"));
const path_1 = __importDefault(require("path"));
const chalk_1 = __importDefault(require("chalk"));
const rootDir = process.cwd();
exports.defaultOptions = {
    directory: '.',
    builtAtFile: '__NGRV_BUILT_AT',
    commitHashFile: '__NGRV_COMMIT_HASH',
    silent: false,
};
const engrave = (options = exports.defaultOptions) => {
    const { directory, builtAtFile, commitHashFile, silent } = Object.assign(Object.assign({}, exports.defaultOptions), options);
    const folderPath = path_1.default.join(rootDir, directory);
    if (!fs_1.default.existsSync(folderPath)) {
        fs_1.default.mkdirSync(folderPath);
    }
    try {
        /**
         * @shell echo $(date -u +'%s')>./__NGRV_BUILT_AT
         */
        const builtAt = Date.now().toString().trim();
        const iso = new Date(parseInt(builtAt, 10)).toISOString();
        const fpath = path_1.default.join(folderPath, builtAtFile);
        console.log(chalk_1.default.greenBright(`[ngrv] saved at ${fpath}`));
        console.log(chalk_1.default.greenBright(`[ngrv] ${builtAtFile}: ${builtAt} (${iso})`));
        fs_1.default.writeFileSync(fpath, builtAt, 'utf8');
    }
    catch (err) {
        console.error(err === null || err === void 0 ? void 0 : err.message);
    }
    try {
        /**
         * @shell echo $(git rev-parse HEAD)>./__NGRV_COMMIT_HASH
         */
        const commitHash = (0, child_process_1.execSync)('git rev-parse HEAD').toString('utf8').trim();
        const fpath = path_1.default.join(folderPath, commitHashFile);
        console.log(chalk_1.default.greenBright(`[ngrv] saved at ${fpath}`));
        console.log(chalk_1.default.greenBright(`[ngrv] ${commitHashFile}: ${commitHash}`));
        fs_1.default.writeFileSync(fpath, commitHash, 'utf8');
    }
    catch (err) {
        console.error(err === null || err === void 0 ? void 0 : err.message);
    }
};
exports.engrave = engrave;
const readEngrave = (options = exports.defaultOptions) => {
    const { directory, builtAtFile, commitHashFile, silent } = Object.assign(Object.assign({}, exports.defaultOptions), options);
    const folderPath = path_1.default.join(rootDir, directory);
    try {
        const fpath = path_1.default.join(folderPath, builtAtFile);
        const builtAt = fs_1.default.readFileSync(fpath, 'utf8').trim();
        process.env[builtAtFile] = builtAt;
        if (!silent) {
            const iso = new Date(parseInt(builtAt, 10)).toISOString();
            console.log(chalk_1.default.greenBright(`[ngrv] read from ${fpath}`));
            console.log(chalk_1.default.greenBright(`[ngrv] ${builtAtFile}: ${builtAt} (${iso})`));
        }
    }
    catch (err) {
        console.error(err === null || err === void 0 ? void 0 : err.message);
    }
    try {
        const fpath = path_1.default.join(folderPath, commitHashFile);
        const commitHash = fs_1.default.readFileSync(fpath, 'utf8').trim();
        process.env[commitHashFile] = commitHash;
        if (!silent) {
            console.log(chalk_1.default.greenBright(`[ngrv] read from ${fpath}`));
            console.log(chalk_1.default.greenBright(`[ngrv] ${commitHashFile}: ${commitHash}`));
        }
    }
    catch (err) {
        console.error(err === null || err === void 0 ? void 0 : err.message);
    }
};
exports.readEngrave = readEngrave;
